.TH lpmex 1 "NOVEMBRE 1998" "Scilab Group" "Scilab Function"
.so ../sci.an
.SH NAME
lp_maker -  Makes mixed integer linear programming problems
.SH CALLING SEQUENCE
 [lp_handle] = lp_maker(f,a,b,e)
 [lp_handle] = lp_maker(f,a,b,e,vlb)
 [lp_handle] = lp_maker(f,a,b,e,vlb,vub)
 [lp_handle] = lp_maker(f,a,b,e,vlb,vub,xint)
 [lp_handle] = lp_maker(f,a,b,e,vlb,vub,xint,autoscale)
 [lp_handle] = lp_maker(f,a,b,e,vlb,vub,xint,autoscale,setminim)

.fi
.SH PARAMETERS
.TP 10
f
: full column vector (objective), size n
.TP 10
a
: sparse or full real matrix, m x n (constraints)
.TP 10
b
: full column vector (constraints), size m
.TP 10
e
: full column vector of row status (integer -1,0 or 1), size m
.TP 10
vlb
: full column vector of lower bounds, size n, (zeros(1,n) is omited) 
.TP 10
vub
: full column vector of upper bounds, size n  (Inf. is omited)
.TP 10
xint
: full column vector of integer,x(int) are integer, size <= n
.TP 10
autoscale
: integer,  flag. Off when 0 or omitted
.TP 10
setminim
: integer, Set maximum lp when this flag equals 0 or omitted
.TP 10
lp_handle 
: integer handle to the lp created

.SH DESCRIPTION
Makes mixed integer linear programming problems.

          max v = f'*x
s.t.        a*x <> b
     0 <= vlb <= x <= vub
                x(int) are integer
.fi
\fV e\fR : m vector that determines the sense of the inequalities:
                   e(i) < 0  ==> Less Than
                   e(i) = 0  ==> Equals
                   e(i) > 0  ==> Greater Than
.fi
.SH EXAMPLE
.nf
//          Var[  1] Var[  2] Var[  3] Var[  4]
//Minimize      2.00     3.00    -2.00     3.00
//Row[  1]      3.00     2.00     2.00     1.00 <=     4.00
//Row[  2]      0.00     4.00     3.00     1.00 >=     3.00
//Type          Real     Real     Real     Real
//upbo           Inf      Inf      Inf      Inf
//lowbo         0.00     0.00     0.00     0.00
       



f = [  2.00     3.00    -2.00     3.00 ];
a = sparse( [ 3.00     2.00     2.00     1.00;
              0.00     4.00     3.00     1.00]);
b = [ 4; 3];
e = [-1;1];

[lp_handle] = lp_maker(f,a,b,e);
.fi
.SH SEE ALSO
lpsolve lpmex mps2hopdm lp_solve


