.TH lpsolve 1 "MARCH 1998" "Scilab Group" "Scilab Function"
.so ../sci.an 
.SH NAME
lpsolve - LP (Higher Order Primal-Dual Method),
.SH CALLING SEQUENCE
.nf
 [x,obj] = lpsolve('file-name')
 [x,obj] = lpsolve('file-name',bounds)
 [x,obj] = lpsolve('file-name',bounds,maxsizes)
 [x,obj] = lpsolve(A,b,c,rwstat)
 [x,obj] = lpsolve(A,b,c,rwstat,lbounds) 
 [x,obj] = lpsolve(A,b,c,rwstat,lbounds,ubounds)
 [x,obj] = lpsolve(A,b,c,rwstat,lbounds,ubounds,xint)
 [x,obj] = lpsolve(A,b,c,rwstat,lbounds,ubounds,xint,autoscale)

.fi
.SH PARAMETERS
.TP 10
file-name
: character string (mps file is 'file-name.mps')
.TP 10
bounds
: 2-vector [lowbounds,upbounds], default lower ans upper bounds
.TP 10
maxsizes
: 3-vector [maxm,maxn,maxnza] Maximum number of contraints and
variables, maximum number of nonzeros entries in the LP con-
straint matrix. If omitted readmps reads the file once just to
compute these numbers.
.TP 10
A   
: sparse real matrix, m x n (constraints) 
.TP 10
b   
: full column vector (constraints), size m
.TP 10
c   
: full column vector (objective), size n
.TP 10
rwstat
: full column vector of row rwstat (integer 1,2,3), size m
.TP 10
lbounds   
: full column vector of lower bounds, size n 
.TP 10
ubounds   
: full column vector of upper bounds, size n
.TP 10
xint
: full column vector integer, x(xint) are integer 
.TP 10
autoscale
: Integer : Autoscale flag. Off when 0 or omitted.
x
: column vector solution
.TP 10
obj   
: value of objective function

.SH DESCRIPTION
Lpsolve solver for the linear program
.nf
     min  c' * x
 s.t.    A * x =  b 
         A * x <  b 
         A * x >  b 
 0 <= lbounds  <= x <= ubounds
     x(int) are integer
.fi
The linear program can described in a file with the mps format
or given as Scilab variables.
.LP
[x,obj] = lpsolve('file-name')
loads the variables saved in file 'file-name.mps' and
solves the linear program. 
.fi
.LP
\fV[x,obj] =
lpsolve(A,b,c,rwstat,lbounds,ubounds,xint,autoscale)\fR.
.LP
rwstat - Vector of row types:
.nf
 1  row type is  = 
 2  row type is >= 
 3  row type is <= 
.fi

.SH EXAMPLE
.nf
File : test.mps (see LPMEXDIR/examples/test.mps)
NAME          TEST
ROWS
 N  COST
 L  LIM1
 G  LIM2
 E  MYEQN
COLUMNS
    XONE      COST                 1   LIM1                 1
    XONE      LIM2                 1
    YTWO      COST                 4   LIM1                 1
    YTWO      MYEQN               -1
    ZTHREE    COST                 9   LIM2                 1
    ZTHREE    MYEQN                1
RHS
    RHS1      LIM1                 5   LIM2                10
    RHS1      MYEQN                7
BOUNDS
 UP BND1      XONE                 4
 LO BND1      YTWO                -1
 UP BND1      YTWO                 1
ENDATA
//// objective:
//   min     XONE + 4 YTWO + 9 ZTHREE
//// constraints:
//  LIM1:    XONE +   YTWO            < = 5
//  LIM2:    XONE +            ZTHREE > = 10
// MYEQN:         -   YTWO  +  ZTHREE   = 7
//// Bounds
//  0 < = XONE < = 4
// -1 < = YTWO < = 1
//// End
[A,b,c,lbounds,ubounds,rwstat,stavar,ranges,name]=mps2hopdm('test');
//3 variables and 3 constraints
c  //cost function
full(A)  //Constraint matrix (full format for display)
[rwstat , b] //[type of constraints, rhs vector]<=>[ [<=;>=;=] ,[5;10;7]]
[rwstat, ranges] //b(1)-ranges(1) <= Ax(1) <= b(1)   (since rwstat(1)=3)
                 //b(2) <= Ax(2) <= Ax(2)+ranges(2)  (since rwstat(1)=2)
	         //Ax(3) = b(3)                      (since rwstat(1)=1)
lbounds     //lower bounds
ubounds(1:2) //"finite" upper bounds
[x0,obj0]=lpsolve(A,b,c,rwstat,lbounds,ubounds)
[x1,obj1] = lpsolve(LPMEXDIR+'/examples/test')
.fi
.SH SEE ALSO
lpmex




